@@ -25,7 +25,7 @@ from urllib3.util.retry import Retry
 from .._utils._constants import WORK_ORDER_STATUS, WORK_ORDER_CATEGORY, WORK_ORDER_PRIORITY
 
 __all__ = ['generate_password', 'convert_to_sqm', 'convert_to_pascal_case', 'ValidatedSetterProperty', 'ApiInputs',
-           'DiscoveryIntegrationInput', 'DataFeedFileProcessOutput', 'requests_retry_session']
+           'DiscoveryIntegrationInput', 'DataFeedFileProcessOutput', 'requests_retry_session', 'is_valid_uuid']
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
@@ -246,6 +246,28 @@ def requests_retry_session(retries=5, status_forcelist=[429, 500, 502, 503, 504]
     session.mount('https://', adapter=adapter)
     return session
 
+def is_valid_uuid(uuid_to_test: Union[uuid.UUID, str], version=4) -> bool:
+    """
+    Check if uuid_to_test is a valid UUID.
+    
+     Parameters
+    ----------
+    uuid_to_test : str
+    version : {1, 2, 3, 4}
+    
+     Returns
+    -------
+    `True` if uuid_to_test is a valid UUID, otherwise `False`.
+    """
+    
+    try:
+        if isinstance(uuid_to_test, uuid.UUID):
+            return uuid_to_test.version == version
+        
+        uuid_obj = uuid.UUID(uuid_to_test, version=version)
+    except ValueError:
+        return False
+    return str(uuid_obj) == uuid_to_test
 
 _site_schema = pandera.DataFrameSchema(
     {
