@@ -7,13 +7,14 @@
 A module containing the helper functions useful when integrating asset creation, asset updates, data ingestion, etc
 into the Switch Automation Platform.
 """
+import json
 import pandas
 import requests
 import datetime
 import logging
 import sys
 from .._utils._constants import SUPPORT_PAYLOAD_TYPE  # , QUERY_LANGUAGE
-from .._utils._utils import ApiInputs
+from .._utils._utils import ApiInputs, requests_retry_session
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
@@ -105,19 +106,84 @@ def _timezone_offsets(api_inputs: ApiInputs, date_from: datetime.date, date_to:
     url = f"{api_inputs.api_base_url}/timezones/offsets"
     logger.info("Sending request: POST %s", url)
 
-    response = requests.post(url, json=payload, headers=headers)
-    response_status = '{} {}'.format(response.status_code, response.reason)
-    if response.status_code != 200:
-        logger.error("API Call was not successful. Response Status: %s. Reason: %s.", response.status_code,
-                     response.reason)
-        return response_status, pandas.DataFrame()
-    elif len(response.text) == 0:
-        logger.error('No data returned for this API call. %s', response.request.url)
-        return response_status, pandas.DataFrame()
+    try:
+        response = requests_retry_session(method_whitelist=['POST']).post(url, json=payload, headers=headers)
 
-    response_data_frame = pandas.read_json(response.text)
+        response_status = '{} {}'.format(response.status_code, response.reason)
+        if response.status_code != 200:
+            logger.error("API Call was not successful. Response Status: %s. Reason: %s.", response.status_code,
+                         response.reason)
+            return response_status, pandas.DataFrame()
+        elif len(response.text) == 0:
+            logger.error('No data returned for this API call. %s', response.request.url)
+            return response_status, pandas.DataFrame()
 
-    return response_data_frame
+        response_data_frame = pandas.read_json(response.text)
+        return response_data_frame
+    except Exception as ex:
+        logger.error("API Call was not successful.", ex)
+        return pandas.DataFrame()
+
+
+def _timezone_dst_offsets(api_inputs: ApiInputs, date_from: datetime.date, date_to: datetime.date,
+                          installation_id_list: list):
+    """Get timezones
+
+    Parameters
+    ----------
+    api_inputs : ApiInputs
+        Object returned by initialize() function.
+    date_from : datetime.date
+        First (earliest) record
+    date_to : datetime.date
+        Last (latest) record
+    installation_id_list : list
+        List of InstallationIDs
+
+    Returns
+    -------
+    df : pandas.DataFrame
+        A dataframe containing the timezone offsets per InstallationID - if multiple timezone offsets occur for the
+        submitted period, there will be a row per offset date range. E.g. for a timezone with daylight savings
+
+    """
+    payload = {
+        "dateFrom": date_from.isoformat(),
+        "dateTo": date_to.isoformat(),
+        "installationIds": installation_id_list
+    }
+
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
+        logger.error("You must call initialize() before using API.")
+        return pandas.DataFrame()
+
+    headers = api_inputs.api_headers.default
+
+    url = f"{api_inputs.api_base_url}/timezones/dst-transitions"
+    logger.info("Sending request: POST %s", url)
+
+    try:
+        response = requests_retry_session(method_whitelist=['POST']).post(url, json=payload, headers=headers)
+
+        response_status = '{} {}'.format(response.status_code, response.reason)
+        if response.status_code != 200:
+            logger.error("API Call was not successful. Response Status: %s. Reason: %s.", response.status_code,
+                         response.reason)
+            return response_status, pandas.DataFrame()
+        elif len(response.text) == 0:
+            logger.error('No data returned for this API call. %s', response.request.url)
+            return response_status, pandas.DataFrame()
+
+        timezone_intervals = json.loads(response.text)
+        site_timezones = pandas.DataFrame.from_dict(timezone_intervals['installationTimezoneList'])
+        timezone_offsets = pandas.DataFrame.from_dict(timezone_intervals['dstTransitions'])
+        timezone_offsets = timezone_offsets.explode('dstIntervals')
+        timezone_offsets = timezone_offsets.reset_index(drop=True).join(timezone_offsets.reset_index(drop=True)
+                                                                        .dstIntervals.apply(pandas.Series)).drop(columns=['dstIntervals'])
+        return site_timezones.merge(timezone_offsets, on='timezoneId')
+    except Exception as ex:
+        logger.error("API Call was not successful.", ex)
+        return pandas.DataFrame()
 
 
 def _upsert_entities_affected_count(api_inputs: ApiInputs, entities_affected_count: int):
